@@ -13,6 +13,7 @@ Usage::
 """
 from typing import Any, Dict, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
@@ -31,14 +32,15 @@ class Exceptions:
 
 class ForecastQueryServiceClient:
     """
-    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.48/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecastquery.html#ForecastQueryService.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.48/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -49,7 +51,7 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.48/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         """
 
     def query_forecast(
@@ -61,5 +63,5 @@ class ForecastQueryServiceClient:
         NextToken: str = None,
     ) -> QueryForecastResponseTypeDef:
         """
-        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.48/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         """
